==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/ResetPasswordToken.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ResetPasswordToken
 */
@JsonPropertyOrder({ ResetPasswordToken.JSON_PROPERTY_RESET_PASSWORD_URL })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ResetPasswordToken implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_RESET_PASSWORD_URL = "resetPasswordUrl";
    private String resetPasswordUrl;

    public ResetPasswordToken() {
    }

    /*
     * @JsonCreator public ResetPasswordToken(
     *
     * @JsonProperty(JSON_PROPERTY_RESET_PASSWORD_URL) String resetPasswordUrl ) { this(); this.resetPasswordUrl =
     * resetPasswordUrl; }
     */

    /**
     * Get resetPasswordUrl
     *
     * @return resetPasswordUrl
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "https://{yourOktaDomain}/signin/reset-password/XE6wE17zmphl3KqAPFxO", value = "")
    @JsonProperty(JSON_PROPERTY_RESET_PASSWORD_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getResetPasswordUrl() {
        return resetPasswordUrl;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ResetPasswordToken resetPasswordToken = (ResetPasswordToken) o;
        return Objects.equals(this.resetPasswordUrl, resetPasswordToken.resetPasswordUrl);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(resetPasswordUrl);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ResetPasswordToken {\n");
        sb.append("    resetPasswordUrl: ").append(toIndentedString(resetPasswordUrl)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/ResetPasswordToken.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ResetPasswordToken
 */
@JsonPropertyOrder({ ResetPasswordToken.JSON_PROPERTY_RESET_PASSWORD_URL })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ResetPasswordToken implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_RESET_PASSWORD_URL = "resetPasswordUrl";
    private String resetPasswordUrl;

    public ResetPasswordToken() {
    }

    /*
     * @JsonCreator public ResetPasswordToken(
     *
     * @JsonProperty(JSON_PROPERTY_RESET_PASSWORD_URL) String resetPasswordUrl ) { this(); this.resetPasswordUrl =
     * resetPasswordUrl; }
     */

    /**
     * Get resetPasswordUrl
     *
     * @return resetPasswordUrl
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "https://{yourOktaDomain}/signin/reset-password/XE6wE17zmphl3KqAPFxO", value = "")
    @JsonProperty(JSON_PROPERTY_RESET_PASSWORD_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getResetPasswordUrl() {
        return resetPasswordUrl;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ResetPasswordToken resetPasswordToken = (ResetPasswordToken) o;
        return Objects.equals(this.resetPasswordUrl, resetPasswordToken.resetPasswordUrl);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(resetPasswordUrl);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ResetPasswordToken {\n");
        sb.append("    resetPasswordUrl: ").append(toIndentedString(resetPasswordUrl)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
